==> PubliForge-2.0.tar.gz: PubliForge-2.0/publiforge/tests/test_models_storages.py <==
# $Id: test_models_storages.py 89ce79ea3a4e 2015/09/19 10:04:06 Patrick $
# -*- coding: utf-8 -*-
"""Tests of ``models.storages`` classes."""

import unittest
from tempfile import mkdtemp

from ..tests import ModelTestCase


# =============================================================================
class UnitTestModelsStoragesStorage(ModelTestCase):
    """Unit test class for ``models.storages.Storage``."""
    # pylint: disable = locally-disabled, C0103, R0904

    _key = 'seekrit'
    _storage_id = '_test_storage'
    _storage_root = mkdtemp()

    # -------------------------------------------------------------------------
    def tearDown(self):
        """Undo the effects ``pyramid.testing.setUp()``."""
        from os.path import exists
        from shutil import rmtree
        from ..models.storages import Storage
        if self.dbsession.query(Storage)\
               .filter_by(storage_id=self._storage_id).first() is not None:
            Storage.delete(self._storage_root, self._storage_id)
        self.dbsession.commit()
        if exists(self._storage_root):
            rmtree(self._storage_root)
        ModelTestCase.tearDown(self)

    # -------------------------------------------------------------------------
    def _make_one(self):
        """Make an ``Storage`` object."""
        from ..models.storages import Storage
        return Storage(
            {'encryption': self._key}, self._storage_id, 'Test storage')

    # -------------------------------------------------------------------------
    def test_constructor(self):
        """[u:models.storages.Storage.__init__]"""
        from ..models.storages import Storage
        storage1 = self._make_one()
        self.dbsession.add(storage1)
        self.dbsession.commit()
        storage2 = self.dbsession.query(Storage)\
            .filter_by(storage_id=storage1.storage_id).first()
        self.assertNotEqual(storage2, None)
        self.assertEqual(storage2.storage_id, storage1.storage_id)
        self.assertEqual(storage2.access, storage1.access)
        self.assertEqual(storage2.vcs_engine, storage1.vcs_engine)
        self.assertEqual(storage2.refresh, storage1.refresh)

    # -------------------------------------------------------------------------
    def test_delete(self):
        """[u:models.storages.Storage.delete]"""
        from os.path import exists, join
        from ..models.storages import Storage
        storage = self._make_one()
        storage_id = storage.storage_id
        self.dbsession.add(storage)
        self.dbsession.commit()
        storage.delete(self._storage_root, storage.storage_id)
        self.dbsession.commit()
        storage = self.dbsession.query(Storage)\
            .filter_by(storage_id=storage_id).first()
        self.assertEqual(storage, None)
        self.assertFalse(exists(join(self._storage_root, storage_id)))


# =============================================================================
class UnitTestModelsStoragesStorageUser(unittest.TestCase):
    """Unit test class for ``models.storages.StorageUser``."""

    _key = 'seekrit'
    _storage_id = '_test_storage'
    _user_id = 1000

    # -------------------------------------------------------------------------
    def _make_one(self):
        """Make a ``StorageUser`` object."""
        from ..models.storages import StorageUser
        return StorageUser(
            self._storage_id, self._user_id, True, 'user', 'user1',
            'sesame', {'encryption': self._key})

    # -------------------------------------------------------------------------
    def test_constructor(self):
        """[u:models.storages.StorageUser.__init__]"""
        from ..lib.utils import encrypt
        storage_user = self._make_one()
        self.assertEqual(storage_user.user_id, self._user_id)
        self.assertTrue(storage_user.in_menu)
        self.assertEqual(storage_user.perm, 'user')
        self.assertEqual(storage_user.vcs_user, 'user1')
        self.assertEqual(
            storage_user.vcs_password, encrypt('sesame', self._key))


# =============================================================================
class IntegrationTestModelsStorages(ModelTestCase):
    """Integration test class for ``models.storages``."""
    # pylint: disable = locally-disabled, C0103

    _key = 'seekrit'
    _user_id = 1000
    _storage_id = '_test_storage'
    _storage_root = mkdtemp()

    # -------------------------------------------------------------------------
    def tearDown(self):
        """Undo the effects ``pyramid.testing.setUp()``."""
        from os.path import exists
        from shutil import rmtree
        from ..models.users import User
        from ..models.storages import Storage
        self.dbsession.query(User).filter_by(user_id=self._user_id).delete()
        if self.dbsession.query(Storage)\
               .filter_by(storage_id=self._storage_id).first() is not None:
            Storage.delete(self._storage_root, self._storage_id)
        self.dbsession.commit()
        if exists(self._storage_root):
            rmtree(self._storage_root)
        ModelTestCase.tearDown(self)

    # -------------------------------------------------------------------------
    def _make_storage(self):
        """Make a ``Storage`` object."""
        # pylint: disable = locally-disabled, E1101
        from ..models.storages import Storage
        return Storage(
            {'encryption': self._key}, self._storage_id, 'Test storage')

    # -------------------------------------------------------------------------
    def _make_user(self):
        """Make an ``User`` object."""
        from ..models.users import User
        user = User({'encryption': self._key}, '_test_user', status='active',
                    password='mypassword', name=u'Gédéon TEUSEMANIE',
                    email='test@prismallia.fr', lang='en')
        user.user_id = self._user_id
        return user

    # -------------------------------------------------------------------------
    def test_delete_user(self):
        """[i:models.storages] remove user"""
        from ..models.users import User
        from ..models.storages import StorageUser
        storage = self._make_storage()
        user = self._make_user()
        self.dbsession.add(user)
        storage.users.append(
            StorageUser(self._storage_id, self._user_id))
        self.dbsession.add(storage)
        self.dbsession.commit()
        self.assertEqual(len(storage.users), 1)
        self.dbsession.query(User).filter_by(user_id=self._user_id).delete()
        self.dbsession.commit()
        self.assertEqual(len(storage.users), 0)

==> PubliForge-2.1.tar.gz: PubliForge-2.1/publiforge/tests/test_models_storages.py <==
# -*- coding: utf-8 -*-
"""Tests of ``models.storages`` classes."""

import unittest
from tempfile import mkdtemp

from ..tests import ModelTestCase


# =============================================================================
class UnitTestModelsStoragesStorage(ModelTestCase):
    """Unit test class for ``models.storages.Storage``."""
    # pylint: disable = C0103, R0904

    _key = 'seekrit'
    _storage_id = '_test_storage'
    _storage_root = mkdtemp()

    # -------------------------------------------------------------------------
    def tearDown(self):
        """Undo the effects ``pyramid.testing.setUp()``."""
        from os.path import exists
        from shutil import rmtree
        from ..models.storages import Storage
        if self.dbsession.query(Storage)\
               .filter_by(storage_id=self._storage_id).first() is not None:
            Storage.delete(self._storage_root, self._storage_id)
        self.dbsession.commit()
        if exists(self._storage_root):
            rmtree(self._storage_root)
        ModelTestCase.tearDown(self)

    # -------------------------------------------------------------------------
    def _make_one(self):
        """Make an ``Storage`` object."""
        from ..models.storages import Storage
        return Storage(
            {'encryption': self._key}, self._storage_id, 'Test storage')

    # -------------------------------------------------------------------------
    def test_constructor(self):
        """[u:models.storages.Storage.__init__]"""
        from ..models.storages import Storage
        storage1 = self._make_one()
        self.dbsession.add(storage1)
        self.dbsession.commit()
        storage2 = self.dbsession.query(Storage)\
            .filter_by(storage_id=storage1.storage_id).first()
        self.assertNotEqual(storage2, None)
        self.assertEqual(storage2.storage_id, storage1.storage_id)
        self.assertEqual(storage2.access, storage1.access)
        self.assertEqual(storage2.vcs_engine, storage1.vcs_engine)
        self.assertEqual(storage2.refresh, storage1.refresh)

    # -------------------------------------------------------------------------
    def test_delete(self):
        """[u:models.storages.Storage.delete]"""
        from os.path import exists, join
        from ..models.storages import Storage
        storage = self._make_one()
        storage_id = storage.storage_id
        self.dbsession.add(storage)
        self.dbsession.commit()
        storage.delete(self._storage_root, storage.storage_id)
        self.dbsession.commit()
        storage = self.dbsession.query(Storage)\
            .filter_by(storage_id=storage_id).first()
        self.assertEqual(storage, None)
        self.assertFalse(exists(join(self._storage_root, storage_id)))


# =============================================================================
class UnitTestModelsStoragesStorageUser(unittest.TestCase):
    """Unit test class for ``models.storages.StorageUser``."""

    _key = 'seekrit'
    _storage_id = '_test_storage'
    _user_id = 1000

    # -------------------------------------------------------------------------
    def _make_one(self):
        """Make a ``StorageUser`` object."""
        from ..models.storages import StorageUser
        return StorageUser(
            self._storage_id, self._user_id, True, 'user', 'user1',
            'sesame', {'encryption': self._key})

    # -------------------------------------------------------------------------
    def test_constructor(self):
        """[u:models.storages.StorageUser.__init__]"""
        from ..lib.utils import encrypt
        storage_user = self._make_one()
        self.assertEqual(storage_user.user_id, self._user_id)
        self.assertTrue(storage_user.in_menu)
        self.assertEqual(storage_user.perm, 'user')
        self.assertEqual(storage_user.vcs_user, 'user1')
        self.assertEqual(
            storage_user.vcs_password, encrypt('sesame', self._key))


# =============================================================================
class IntegrationTestModelsStorages(ModelTestCase):
    """Integration test class for ``models.storages``."""
    # pylint: disable = C0103

    _key = 'seekrit'
    _user_id = 1000
    _storage_id = '_test_storage'
    _storage_root = mkdtemp()

    # -------------------------------------------------------------------------
    def tearDown(self):
        """Undo the effects ``pyramid.testing.setUp()``."""
        from os.path import exists
        from shutil import rmtree
        from ..models.users import User
        from ..models.storages import Storage
        self.dbsession.query(User).filter_by(user_id=self._user_id).delete()
        if self.dbsession.query(Storage)\
               .filter_by(storage_id=self._storage_id).first() is not None:
            Storage.delete(self._storage_root, self._storage_id)
        self.dbsession.commit()
        if exists(self._storage_root):
            rmtree(self._storage_root)
        ModelTestCase.tearDown(self)

    # -------------------------------------------------------------------------
    def _make_storage(self):
        """Make a ``Storage`` object."""
        # pylint: disable = E1101
        from ..models.storages import Storage
        return Storage(
            {'encryption': self._key}, self._storage_id, 'Test storage')

    # -------------------------------------------------------------------------
    def _make_user(self):
        """Make an ``User`` object."""
        from ..models.users import User
        user = User({'encryption': self._key}, '_test_user', status='active',
                    password='mypassword', name=u'Gédéon TEUSEMANIE',
                    email='test@prismallia.fr', lang='en')
        user.user_id = self._user_id
        return user

    # -------------------------------------------------------------------------
    def test_delete_user(self):
        """[i:models.storages] remove user"""
        from ..models.users import User
        from ..models.storages import StorageUser
        storage = self._make_storage()
        user = self._make_user()
        self.dbsession.add(user)
        storage.users.append(
            StorageUser(self._storage_id, self._user_id))
        self.dbsession.add(storage)
        self.dbsession.commit()
        self.assertEqual(len(storage.users), 1)
        self.dbsession.query(User).filter_by(user_id=self._user_id).delete()
        self.dbsession.commit()
        self.assertEqual(len(storage.users), 0)
